==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPinColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnEventArgsDetailDescriptionMetadata } from "./WebPinColumnEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDescription } from "./WebPinColumnEventArgsDescription";
/**
 * @hidden
 */
export let WebPinColumnEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnEventArgsDescriptionMetadata.a == null) {
                WebPinColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnEventArgsDescriptionMetadata.c(WebPinColumnEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPinColumnEventArgsDescriptionMetadata.a);
            WebPinColumnEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PinColumnEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPinColumnEventArgsDetail");
        }
        static d(a) {
            WebPinColumnEventArgsDescriptionMetadata.b(a);
            a.ad("WebPinColumnEventArgs", () => new WebPinColumnEventArgsDescription());
            a.ac("WebPinColumnEventArgs", WebPinColumnEventArgsDescriptionMetadata.a);
        }
    }
    WebPinColumnEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnEventArgsDescriptionMetadata, 'WebPinColumnEventArgsDescriptionMetadata');
    WebPinColumnEventArgsDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebPinColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnEventArgsDetailDescriptionMetadata } from "./WebPinColumnEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDescription } from "./WebPinColumnEventArgsDescription";
/**
 * @hidden
 */
export let WebPinColumnEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnEventArgsDescriptionMetadata.a == null) {
                WebPinColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnEventArgsDescriptionMetadata.c(WebPinColumnEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPinColumnEventArgsDescriptionMetadata.a);
            WebPinColumnEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PinColumnEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPinColumnEventArgsDetail");
        }
        static d(a) {
            WebPinColumnEventArgsDescriptionMetadata.b(a);
            a.ae("WebPinColumnEventArgs", () => new WebPinColumnEventArgsDescription());
            a.ad("WebPinColumnEventArgs", WebPinColumnEventArgsDescriptionMetadata.a);
        }
    }
    WebPinColumnEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPinColumnEventArgsDescriptionMetadata, 'WebPinColumnEventArgsDescriptionMetadata');
    WebPinColumnEventArgsDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDescriptionMetadata;
})();
